Export a COM(P)ADRE database to a Matlab-friendly flat text file
Source:R/cdb_export_matlab.R
cdb_export_matlab.RdExports a CompadreDB object to a delimited text file that can be read
directly into Matlab with functions such as readtable(). Matrices and
stage vectors are converted to string representation using
cdb_flatten, so each database row remains a single tabular row
in the output file.
Usage
cdb_export_matlab(cdb, file, format = c("csv", "tsv"), na = "NA", quote = TRUE)See also
Other data management:
cdb_flatten(),
cdb_id(),
cdb_id_stages(),
cdb_id_studies(),
cdb_mean_matF(),
cdb_rbind(),
cdb_unflatten(),
cdb_unnest(),
mpm_elementwise_apply(),
mpm_mean(),
mpm_median(),
mpm_sd(),
string_representation
Examples
if (FALSE) { # \dontrun{
out_file <- tempfile(fileext = ".csv")
cdb_export_matlab(Compadre, out_file)
} # }