View source: R/cdb_export_matlab.R
| cdb_export_matlab | R Documentation |
Exports a CompadreDB object to a delimited text file that can be read
directly into Matlab with functions such as readtable(). Matrices and
stage vectors are converted to string representation using
cdb_flatten, so each database row remains a single tabular row
in the output file.
cdb_export_matlab(cdb, file, format = c("csv", "tsv"), na = "NA", quote = TRUE)
cdb |
A CompadreDB object |
file |
Path to the output text file |
format |
Output format. Either |
na |
String to use for missing values in the exported file |
quote |
Logical indicating whether character fields should be quoted |
Invisibly returns the normalized path to the written file
Owen R. Jones <jones@biology.sdu.dk>
Other data management:
cdb_flatten(),
cdb_id(),
cdb_id_stages(),
cdb_id_studies(),
cdb_mean_matF(),
cdb_rbind(),
cdb_unflatten(),
cdb_unnest(),
mpm_elementwise_apply(),
mpm_mean(),
mpm_median(),
mpm_sd(),
string_representation
## Not run:
out_file <- tempfile(fileext = ".csv")
cdb_export_matlab(Compadre, out_file)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.